==> dotnet6_6.0.136.orig.tar.xz: src/runtime/src/libraries/System.ComponentModel.Composition/src/System/ComponentModel/Composition/ChangeRejectedException.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System.Collections.Generic;
using System.Globalization;

namespace System.ComponentModel.Composition
{
    /// <summary>
    ///     The exception that is thrown when one or more recoverable errors occur during
    ///     composition which results in those changes being rejected.
    /// </summary>
    public class ChangeRejectedException : CompositionException
    {
        /// <summary>
        ///     Initializes a new instance of the <see cref="ChangeRejectedException"/> class.
        /// </summary>
        public ChangeRejectedException()
            : this((string?)null, (Exception?)null)
        {
        }

        /// <summary>
        ///     Initializes a new instance of the <see cref="ChangeRejectedException"/> class.
        /// </summary>
        public ChangeRejectedException(string? message)
            : this(message, (Exception?)null)
        {
        }

        /// <summary>
        ///     Initializes a new instance of the <see cref="ChangeRejectedException"/> class.
        /// </summary>
        public ChangeRejectedException(string? message, Exception? innerException)
            : base(message, innerException, (IEnumerable<CompositionError>?)null)
        {
        }

        /// <summary>
        ///     Initializes a new instance of the <see cref="ChangeRejectedException"/> class.
        /// </summary>
        /// <param name="errors">List of errors that occured while applying the changes.</param>
        public ChangeRejectedException(IEnumerable<CompositionError>? errors)
            : base((string?)null, (Exception?)null, errors)
        {
        }

        /// <summary>
        ///     Gets a message that describes the exception.
        /// </summary>
        /// <value>
        ///     A <see cref="string"/> containing a message that describes the
        ///     <see cref="ChangeRejectedException"/>.
        /// </value>
        public override string Message
        {
            get
            {
                return SR.Format(
                    SR.CompositionException_ChangesRejected,
                    base.Message);
            }
        }
    }
}

==> dotnet8_8.0.115-8.0.15.orig.tar.xz: src/runtime/src/libraries/System.ComponentModel.Composition/src/System/ComponentModel/Composition/ChangeRejectedException.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System.Collections.Generic;
using System.Globalization;

namespace System.ComponentModel.Composition
{
    /// <summary>
    ///     The exception that is thrown when one or more recoverable errors occur during
    ///     composition which results in those changes being rejected.
    /// </summary>
    public class ChangeRejectedException : CompositionException
    {
        /// <summary>
        ///     Initializes a new instance of the <see cref="ChangeRejectedException"/> class.
        /// </summary>
        public ChangeRejectedException()
            : this((string?)null, (Exception?)null)
        {
        }

        /// <summary>
        ///     Initializes a new instance of the <see cref="ChangeRejectedException"/> class.
        /// </summary>
        public ChangeRejectedException(string? message)
            : this(message, (Exception?)null)
        {
        }

        /// <summary>
        ///     Initializes a new instance of the <see cref="ChangeRejectedException"/> class.
        /// </summary>
        public ChangeRejectedException(string? message, Exception? innerException)
            : base(message, innerException, (IEnumerable<CompositionError>?)null)
        {
        }

        /// <summary>
        ///     Initializes a new instance of the <see cref="ChangeRejectedException"/> class.
        /// </summary>
        /// <param name="errors">List of errors that occurred while applying the changes.</param>
        public ChangeRejectedException(IEnumerable<CompositionError>? errors)
            : base((string?)null, (Exception?)null, errors)
        {
        }

        /// <summary>
        ///     Gets a message that describes the exception.
        /// </summary>
        /// <value>
        ///     A <see cref="string"/> containing a message that describes the
        ///     <see cref="ChangeRejectedException"/>.
        /// </value>
        public override string Message
        {
            get
            {
                return SR.Format(
                    SR.CompositionException_ChangesRejected,
                    base.Message);
            }
        }
    }
}
